'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _spectacle = require('spectacle');

var Core = _interopRequireWildcard(_spectacle);

var _sanitizeHtml = require('sanitize-html');

var _sanitizeHtml2 = _interopRequireDefault(_sanitizeHtml);

var _theme = require('../theme');

var _theme2 = _interopRequireDefault(_theme);

var _syntax = require('./syntax');

var _syntax2 = _interopRequireDefault(_syntax);

var _migrations = require('../migrations');

var _migrations2 = _interopRequireDefault(_migrations);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Spectacle = Core.Spectacle,
    Deck = Core.Deck,
    Slide = Core.Slide,
    Appear = Core.Appear;


Core.Plotly = function (props) {
  return _react2.default.createElement('iframe', props);
};
Core.CodePane = _syntax2.default; // Use custom Syntax component for CodePane

var quoteStyles = {
  borderLeftWidth: '0.05em',
  borderLeftStyle: 'solid',
  borderLeftColor: 'inherit',
  paddingLeft: '0.5em'
};

var getStylesForText = function getStylesForText(props, paragraphStyles) {
  return Object.assign({}, paragraphStyles[props.paragraphStyle], props.style);
};

var escapeHtml = function escapeHtml(str) {
  var div = document.createElement("div");
  div.appendChild(document.createTextNode(str));
  return div.innerHTML;
};

var whitelistedProtocols = ['http://', 'https://', 'mailto://', 'data:image/gif', 'data:image/png', 'data:image/jpeg', 'data:image/webp'];

var isDangerousUrl = function isDangerousUrl(url) {
  return !whitelistedProtocols.some(function (proto) {
    return url.startsWith(proto);
  });
};

// Prepend an http:// in front of any markdown links that don't begin with a valid protocol such as
// javascript:, data:, etc. This will obviously point to a bad URL but it won't allow anything
// malicious to execute.
var sanitizeMarkdown = function sanitizeMarkdown(markdown) {
  return markdown.replace(/\(([a-z]+):/ig, function (match, proto) {
    if (!whitelistedProtocols.includes(proto)) {
      return match.replace(proto, 'http://');
    }
    return match;
  });
};

var renderChildren = function renderChildren(nodes, paragraphStyles, isListItem) {
  return nodes.map(function (node, i) {
    // Text node
    if (typeof node === 'string') {
      var contents = escapeHtml(node).replace(/\n/g, '<br>');
      if (isListItem) {
        return _react2.default.createElement('li', { key: 'line-' + i, style: _theme2.default.components.listItem, dangerouslySetInnerHTML: { __html: contents } });
      }
      return _react2.default.createElement('span', { key: 'line-' + i, style: { width: "100%", display: "block" }, dangerouslySetInnerHTML: { __html: contents } });
    }

    // defaultText handling
    if (node.type === 'Text' && !node.children) {
      return node.defaultText;
    }

    var type = node.type,
        children = node.children,
        props = node.props;

    // Get component from Spectacle core

    var Tag = Core[type];

    /* eslint-disable react/prop-types */
    if (props.isQuote) {
      props.style = Object.assign({}, props.style, quoteStyles);
    }

    // Trap javascript: protocol links and replace with an href that does nothing
    var urlPropNames = ['href', 'src'];
    urlPropNames.forEach(function (propName) {
      if (props[propName] && isDangerousUrl(props[propName])) {
        props[propName] = "javascript:;";
      }
    });

    if (type === 'Markdown' && props.source) {
      // Sanitize markdown source
      props.source = sanitizeMarkdown(props.source);
    }

    if (type === 'Text' && !props.listType) {
      var _contents = void 0;
      if (props.href) {
        _contents = _react2.default.createElement(
          'a',
          { href: props.href, style: { textDecoration: 'inherit', color: 'inherit' } },
          renderChildren(children, paragraphStyles)
        );
      } else {
        _contents = renderChildren(children, paragraphStyles);
      }

      return _react2.default.createElement(
        Tag,
        _extends({ key: node.id }, props, { style: _extends({}, getStylesForText(props, paragraphStyles)) }),
        _contents
      );
      /* eslint-enable react/prop-types */
    }

    if (type === 'Text' && props.listType) {
      Tag = props.listType === 'ordered' ? 'ol' : 'ul';

      return _react2.default.createElement(
        Tag,
        {
          key: node.id,
          className: 'presentation-list',
          style: _extends({}, getStylesForText(props, paragraphStyles), { margin: 0 })
        },
        children && renderChildren(children, paragraphStyles, true)
      );
    }

    // Render and recurse
    return _react2.default.createElement(
      Tag,
      _extends({ key: node.id }, props),
      children && renderChildren(children, paragraphStyles)
    );
  });
};

var slideStyles = {
  flexDirection: "column"
};

var innerStyles = {
  height: 700,
  width: 1000,
  padding: 40
};

var renderSlides = function renderSlides(_ref) {
  var slides = _ref.slides,
      paragraphStyles = _ref.paragraphStyles;
  return slides.map(function (slide) {
    if (slide.props.notes) {
      slide.props.notes = (0, _sanitizeHtml2.default)(slide.props.notes);
    }

    return _react2.default.createElement(
      Slide,
      _extends({ key: slide.id }, slide.props, { style: _extends({}, slide.props.style, slideStyles), viewerScaleMode: true }),
      _react2.default.createElement(
        'div',
        { style: innerStyles },
        slide.children && renderChildren(slide.children, paragraphStyles)
      )
    );
  });
};

var Viewer = function Viewer(props) {
  var presentation = (0, _migrations2.default)(props.content.presentation);
  return _react2.default.createElement(
    Spectacle,
    { theme: { screen: _theme2.default, print: _theme2.default }, history: props.history },
    _react2.default.createElement(
      Deck,
      { transition: [], globalStyles: false, progress: 'none' },
      renderSlides(presentation)
    )
  );
};

Viewer.propTypes = {
  content: _react.PropTypes.object,
  history: _react.PropTypes.object
};

exports.default = Viewer;